//
// Copyright (c) ZeroC, Inc. All rights reserved.
//

require("core-js/stable");
require("regenerator-runtime/runtime");

module.exports.Ice = require("./Ice/Ice").Ice;
module.exports.IceMX = require("./Ice/Ice").IceMX;
module.exports.IceSSL = require("./Ice/Ice").IceSSL;
module.exports.Glacier2 = require("./Glacier2/Glacier2").Glacier2;
module.exports.IceGrid = require("./IceGrid/IceGrid").IceGrid;
module.exports.IceStorm = require("./IceStorm/IceStorm").IceStorm;
